#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.5.0
visibility:           public
id:                   stylish-haskell-0.14.5.0-90zJtr3UwY5EReziPPDATs
key:                  stylish-haskell-0.14.5.0-90zJtr3UwY5EReziPPDATs
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  c44954609c3018fc66f3dd3f668324c8
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stylish-haskell-0.14.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.5.0-90zJtr3UwY5EReziPPDATs
depends:
    Cabal-3.10.3.0 HsYAML-0.2.1.5-Ay9Y8vAGLceJmW9Z3MuX0y
    HsYAML-aeson-0.2.0.2-Ge3jdW1AECJQZIfww8txp
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-9.6.6 ghc-boot-th-9.6.6
    ghc-lib-parser-ex-9.6.0.2-AcjcEvmfYqg7OAlYL1ufzz mtl-2.3.1
    regex-tdfa-1.3.2.5-6VokBrH99ZuK2RS5akjMTl
    syb-0.7.3-9nTxFCe6QUcL36iCSC2LiM text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

